==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
var WebDropdownItemComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDropdownItemComponentEventArgsDescriptionMetadata, _super);
    function WebDropdownItemComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        WebDropdownItemDescriptionMetadata.d(a);
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
        a.item("Detail", "ExportedType:WebDropdownItem");
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.d = function (a) {
        WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
        a.u("WebDropdownItemComponentEventArgs", function () { return new WebDropdownItemComponentEventArgsDescription(); });
        a.t("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
}(Base));
export { WebDropdownItemComponentEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDropdownItemComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebDropdownItemComponentEventArgsDescription } from "./WebDropdownItemComponentEventArgsDescription";
/**
 * @hidden
 */
var WebDropdownItemComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDropdownItemComponentEventArgsDescriptionMetadata, _super);
    function WebDropdownItemComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownItemComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebDropdownItemComponentEventArgsDescriptionMetadata.a == null) {
            WebDropdownItemComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownItemComponentEventArgsDescriptionMetadata.c(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebDropdownItemComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDropdownItemComponentEventArgsDescriptionMetadata.a);
        WebDropdownItemDescriptionMetadata.d(a);
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DropdownItemComponentEventArgs");
        a.item("Detail", "ExportedType:WebDropdownItem");
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.d = function (a) {
        WebDropdownItemComponentEventArgsDescriptionMetadata.b(a);
        a.aa("WebDropdownItemComponentEventArgs", function () { return new WebDropdownItemComponentEventArgsDescription(); });
        a.z("WebDropdownItemComponentEventArgs", WebDropdownItemComponentEventArgsDescriptionMetadata.a);
    };
    WebDropdownItemComponentEventArgsDescriptionMetadata.$t = markType(WebDropdownItemComponentEventArgsDescriptionMetadata, 'WebDropdownItemComponentEventArgsDescriptionMetadata');
    WebDropdownItemComponentEventArgsDescriptionMetadata.a = null;
    return WebDropdownItemComponentEventArgsDescriptionMetadata;
}(Base));
export { WebDropdownItemComponentEventArgsDescriptionMetadata };
